# WinTmp

This is a Python module used to getting temperatures of the CPU and GPU in windows. If this module doesn't work, please open an issue!

This module needs to be run as administrator.

Install:
`pip install WinTmp`

In admin command prompt type `python`.
Demo:

```python
>>> import WinTmp
>>> print(WinTmp.CPU_Temp())
38.0
>>> print(WinTmp.GPU_Temp())
35.0
>>>
```

PyPI: https://pypi.org/project/WinTmp/

Github: https://github.com/kethan1/WinTmp/
